@@ -40,6 +40,9 @@ pub struct Config {
 
     #[serde(default)]
     pub speaker_notes: SpeakerNotesConfig,
+
+    #[serde(default)]
+    pub export: ExportConfig,
 }
 
 impl Config {
@@ -94,6 +97,10 @@ pub struct DefaultsConfig {
     /// larger than that.
     #[serde(default)]
     pub max_columns_alignment: MaxColumnsAlignment,
+
+    /// The configuration for lists when incremental lists are enabled.
+    #[serde(default)]
+    pub incremental_lists: IncrementalListsConfig,
 }
 
 impl Default for DefaultsConfig {
@@ -105,10 +112,24 @@ impl Default for DefaultsConfig {
             validate_overflows: Default::default(),
             max_columns: default_max_columns(),
             max_columns_alignment: Default::default(),
+            incremental_lists: Default::default(),
         }
     }
 }
 
+/// The configuration for lists when incremental lists are enabled.
+#[derive(Clone, Debug, Default, Deserialize, JsonSchema)]
+#[serde(deny_unknown_fields)]
+pub struct IncrementalListsConfig {
+    /// Whether to pause before a list begins.
+    #[serde(default)]
+    pub pause_before: Option<bool>,
+
+    /// Whether to pause after a list ends.
+    #[serde(default)]
+    pub pause_after: Option<bool>,
+}
+
 fn default_terminal_font_size() -> u8 {
     16
 }
@@ -441,6 +462,25 @@ impl Default for SpeakerNotesConfig {
     }
 }
 
+/// The export configuration.
+#[derive(Clone, Debug, Default, Deserialize, JsonSchema)]
+#[serde(deny_unknown_fields)]
+pub struct ExportConfig {
+    /// The dimensions to use for presentation exports.
+    pub dimensions: Option<ExportDimensionsConfig>,
+}
+
+/// The dimensions to use for presentation exports.
+#[derive(Clone, Debug, Deserialize, JsonSchema)]
+#[serde(deny_unknown_fields)]
+pub struct ExportDimensionsConfig {
+    /// The number of rows.
+    pub rows: u16,
+
+    /// The number of columns.
+    pub columns: u16,
+}
+
 fn make_keybindings<const N: usize>(raw_bindings: [&str; N]) -> Vec<KeyBinding> {
     let mut bindings = Vec::new();
     for binding in raw_bindings {
