@@ -1,5 +1,5 @@
 use crate::{
-    ImageRegistry, MarkdownParser, PresentationBuilderOptions, PresentationTheme, Resources, Themes, ThirdPartyRender,
+    ImageRegistry, MarkdownParser, PresentationBuilderOptions, Resources, ThemeOptions, Themes, ThirdPartyRender,
     code::execute::SnippetExecutor,
     commands::{
         keyboard::{CommandKeyBindings, KeyboardListener},
@@ -11,7 +11,8 @@ use crate::{
         builder::{BuildError, PresentationBuilder},
     },
     render::TerminalDrawer,
-    terminal::TerminalWrite,
+    terminal::emulator::TerminalEmulator,
+    theme::raw::PresentationTheme,
 };
 use std::{io, rc::Rc};
 
@@ -40,16 +41,16 @@ fn greet(name: &str) -> String {
 <!-- end_slide -->
 "#;
 
-pub struct ThemesDemo<W: TerminalWrite> {
+pub struct ThemesDemo {
     themes: Themes,
     input: KeyboardListener,
-    drawer: TerminalDrawer<W>,
+    drawer: TerminalDrawer,
 }
 
-impl<W: TerminalWrite> ThemesDemo<W> {
-    pub fn new(themes: Themes, bindings: CommandKeyBindings, writer: W) -> io::Result<Self> {
+impl ThemesDemo {
+    pub fn new(themes: Themes, bindings: CommandKeyBindings) -> io::Result<Self> {
         let input = KeyboardListener::new(bindings);
-        let drawer = TerminalDrawer::new(writer, Default::default(), Default::default())?;
+        let drawer = TerminalDrawer::new(Default::default(), Default::default())?;
         Ok(Self { themes, input, drawer })
     }
 
@@ -102,21 +103,24 @@ impl<W: TerminalWrite> ThemesDemo<W> {
         theme: &PresentationTheme,
     ) -> Result<Presentation, BuildError> {
         let image_registry = ImageRegistry::default();
-        let mut resources = Resources::new("non_existent", image_registry.clone());
+        let resources = Resources::new("non_existent", "non_existent", image_registry.clone());
         let mut third_party = ThirdPartyRender::default();
-        let options = PresentationBuilderOptions::default();
+        let options = PresentationBuilderOptions {
+            theme_options: ThemeOptions { font_size_supported: TerminalEmulator::capabilities().font_size },
+            ..Default::default()
+        };
         let executer = Rc::new(SnippetExecutor::default());
         let bindings_config = Default::default();
         let builder = PresentationBuilder::new(
             theme,
-            &mut resources,
+            resources,
             &mut third_party,
             executer,
             &self.themes,
             image_registry,
             bindings_config,
             options,
-        );
+        )?;
         let mut elements = vec![MarkdownElement::SetexHeading { text: format!("theme: {theme_name}").into() }];
         elements.extend(base_elements.iter().cloned());
         builder.build(elements)
