@@ -3,6 +3,7 @@ use super::{
     html::{HtmlInline, HtmlParser, ParseHtmlError},
     text_style::TextStyle,
 };
+use crate::theme::raw::RawColor;
 use comrak::{
     Arena, ComrakOptions,
     arena_tree::Node,
@@ -32,6 +33,7 @@ impl Default for ParserOptions {
         options.extension.strikethrough = true;
         options.extension.multiline_block_quotes = true;
         options.extension.alerts = true;
+        options.extension.wikilinks_title_before_pipe = true;
         Self(options)
     }
 }
@@ -61,6 +63,35 @@ impl<'a> MarkdownParser<'a> {
         Ok(elements)
     }
 
+    /// Parse inlines in a markdown input.
+    pub(crate) fn parse_inlines(&self, line: &str) -> Result<Line<RawColor>, ParseInlinesError> {
+        let node = parse_document(self.arena, line, &self.options);
+        if node.children().count() == 0 {
+            return Ok(Default::default());
+        }
+        if node.children().count() > 1 {
+            return Err(ParseInlinesError("inline must be simple text".into()));
+        }
+        let node = node.first_child().expect("must have one child");
+        let data = node.data.borrow();
+        let NodeValue::Paragraph = &data.value else {
+            return Err(ParseInlinesError("inline must be simple text".into()));
+        };
+        let parser = InlinesParser::new(self.arena, SoftBreak::Space, StringifyImages::No);
+        let inlines = parser.parse(node).map_err(|e| ParseInlinesError(e.to_string()))?;
+        let mut output = Line::default();
+        for inline in inlines {
+            match inline {
+                Inline::Text(line) => {
+                    output.0.extend(line.0);
+                }
+                Inline::Image { .. } => return Err(ParseInlinesError("images not supported".into())),
+                Inline::LineBreak => return Err(ParseInlinesError("line breaks not supported".into())),
+            };
+        }
+        Ok(output)
+    }
+
     fn parse_node(&self, node: &'a AstNode<'a>) -> ParseResult<Vec<MarkdownElement>> {
         let data = node.data.borrow();
         let element = match &data.value {
@@ -117,7 +148,7 @@ impl<'a> MarkdownParser<'a> {
                 Inline::Image { .. } => {}
             }
         }
-        if lines.last() == Some(&Line::from("")) {
+        if lines.last() == Some(&Line::<RawColor>::from("")) {
             lines.pop();
         }
         Ok(MarkdownElement::BlockQuote(lines))
@@ -174,7 +205,7 @@ impl<'a> MarkdownParser<'a> {
         Ok(elements)
     }
 
-    fn parse_text(&self, node: &'a AstNode<'a>) -> ParseResult<Line> {
+    fn parse_text(&self, node: &'a AstNode<'a>) -> ParseResult<Line<RawColor>> {
         let inlines = InlinesParser::new(self.arena, SoftBreak::Space, StringifyImages::No).parse(node)?;
         let mut chunks = Vec::new();
         for inline in inlines {
@@ -212,8 +243,8 @@ impl<'a> MarkdownParser<'a> {
     fn parse_list_item(&self, item: &NodeList, root: &'a AstNode<'a>, depth: u8) -> ParseResult<Vec<ListItem>> {
         let item_type = match (item.list_type, item.delimiter) {
             (ListType::Bullet, _) => ListItemType::Unordered,
-            (ListType::Ordered, ListDelimType::Paren) => ListItemType::OrderedParens,
-            (ListType::Ordered, ListDelimType::Period) => ListItemType::OrderedPeriod,
+            (ListType::Ordered, ListDelimType::Paren) => ListItemType::OrderedParens(item.start),
+            (ListType::Ordered, ListDelimType::Period) => ListItemType::OrderedPeriod(item.start),
         };
         let mut elements = Vec::new();
         for node in root.children() {
@@ -290,7 +321,7 @@ enum StringifyImages {
 
 struct InlinesParser<'a> {
     inlines: Vec<Inline>,
-    pending_text: Vec<Text>,
+    pending_text: Vec<Text<RawColor>>,
     arena: &'a Arena<AstNode<'a>>,
     soft_break: SoftBreak,
     stringify_images: StringifyImages,
@@ -318,7 +349,7 @@ impl<'a> InlinesParser<'a> {
         &mut self,
         node: &'a AstNode<'a>,
         parent: &'a AstNode<'a>,
-        style: TextStyle,
+        style: TextStyle<RawColor>,
     ) -> ParseResult<Option<HtmlStyle>> {
         let data = node.data.borrow();
         match &data.value {
@@ -355,6 +386,9 @@ impl<'a> InlinesParser<'a> {
                     self.pending_text.push(Text::from(")"));
                 }
             }
+            NodeValue::WikiLink(link) => {
+                self.pending_text.push(Text::new(link.url.clone(), TextStyle::default().link_url()));
+            }
             NodeValue::LineBreak => {
                 self.store_pending_text();
                 self.inlines.push(Inline::LineBreak);
@@ -422,18 +456,18 @@ impl<'a> InlinesParser<'a> {
         Ok(None)
     }
 
-    fn process_children(&mut self, root: &'a AstNode<'a>, base_style: TextStyle) -> ParseResult<()> {
+    fn process_children(&mut self, root: &'a AstNode<'a>, base_style: TextStyle<RawColor>) -> ParseResult<()> {
         let mut html_styles = Vec::new();
-        let mut style = base_style;
+        let mut style = base_style.clone();
         for node in root.children() {
-            if let Some(html_style) = self.process_node(node, root, style)? {
+            if let Some(html_style) = self.process_node(node, root, style.clone())? {
                 match html_style {
                     HtmlStyle::Add(style) => html_styles.push(style),
                     HtmlStyle::Remove => {
                         html_styles.pop();
                     }
                 };
-                style = base_style;
+                style = base_style.clone();
                 for html_style in html_styles.iter().rev() {
                     style.merge(html_style);
                 }
@@ -444,12 +478,12 @@ impl<'a> InlinesParser<'a> {
 }
 
 enum HtmlStyle {
-    Add(TextStyle),
+    Add(TextStyle<RawColor>),
     Remove,
 }
 
 enum Inline {
-    Text(Line),
+    Text(Line<RawColor>),
     Image { path: String, title: String },
     LineBreak,
 }
@@ -577,10 +611,15 @@ impl Identifier for NodeValue {
     }
 }
 
+#[derive(Debug, thiserror::Error)]
+#[error("invalid markdown line: {0}")]
+pub(crate) struct ParseInlinesError(String);
+
 #[cfg(test)]
 mod test {
-    use super::*;
     use crate::markdown::text_style::Color;
+
+    use super::*;
     use rstest::rstest;
     use std::path::Path;
 
@@ -713,6 +752,16 @@ boop
         assert_eq!(elements, expected_elements);
     }
 
+    #[test]
+    fn wikilink_wo_title() {
+        let parsed = parse_single("[[https://example.com]]");
+        let MarkdownElement::Paragraph(elements) = parsed else { panic!("not a paragraph: {parsed:?}") };
+        let expected_chunks = vec![Text::new("https://example.com", TextStyle::default().link_url())];
+
+        let expected_elements = &[Line(expected_chunks)];
+        assert_eq!(elements, expected_elements);
+    }
+
     #[test]
     fn image() {
         let parsed = parse_single("![](potato.png)");
@@ -773,6 +822,26 @@ Title
         assert_eq!(next().depth, 0);
     }
 
+    #[test]
+    fn ordered_list_starting_non_one() {
+        let parsed = parse_single(
+            r"
+ 4. One
+    1. Sub1
+    2. Sub2
+ 5. Two
+ 6. Three",
+        );
+        let MarkdownElement::List(items) = parsed else { panic!("not a list: {parsed:?}") };
+        let mut items = items.into_iter();
+        let mut next = || items.next().expect("list ended prematurely");
+        assert_eq!(next().item_type, ListItemType::OrderedPeriod(4));
+        assert_eq!(next().item_type, ListItemType::OrderedPeriod(1));
+        assert_eq!(next().item_type, ListItemType::OrderedPeriod(2));
+        assert_eq!(next().item_type, ListItemType::OrderedPeriod(5));
+        assert_eq!(next().item_type, ListItemType::OrderedPeriod(6));
+    }
+
     #[test]
     fn line_breaks() {
         let parsed = parse_all(
@@ -993,4 +1062,19 @@ mom
         };
         assert_eq!(lines.len(), 2);
     }
+
+    #[test]
+    fn parse_inlines() {
+        let arena = Arena::new();
+        let input = "hello **mom** how _are you_?";
+        let parsed = MarkdownParser::new(&arena).parse_inlines(input).expect("parse failed");
+        let expected = &[
+            "hello ".into(),
+            Text::new("mom", TextStyle::default().bold()),
+            " how ".into(),
+            Text::new("are you", TextStyle::default().italics()),
+            "?".into(),
+        ];
+        assert_eq!(parsed.0, expected);
+    }
 }
