@@ -105,7 +105,7 @@ impl PresentationTheme {
             Heading4 => self.headings.h4.alignment,
             Heading5 => self.headings.h5.alignment,
             Heading6 => self.headings.h6.alignment,
-            Paragraph | List => Default::default(),
+            Paragraph => Default::default(),
             PresentationTitle => self.intro_slide.title.alignment,
             PresentationSubTitle => self.intro_slide.subtitle.alignment,
             PresentationEvent => self.intro_slide.event.alignment,
@@ -444,6 +444,15 @@ pub(crate) enum Alignment {
     Center { minimum_margin: Margin, minimum_size: u16 },
 }
 
+impl Alignment {
+    pub(crate) fn adjust_size(&self, size: u16) -> u16 {
+        match self {
+            Self::Left { .. } | Self::Right { .. } => size,
+            Self::Center { minimum_size, .. } => size.max(*minimum_size),
+        }
+    }
+}
+
 impl From<raw::Alignment> for Alignment {
     fn from(alignment: raw::Alignment) -> Self {
         match alignment {
@@ -618,7 +627,6 @@ pub(crate) enum ElementType {
     Heading5,
     Heading6,
     Paragraph,
-    List,
     PresentationTitle,
     PresentationSubTitle,
     PresentationEvent,
